@@ -2,7 +2,7 @@
  *
  * flickcurl.h - Flickcurl API
  *
- * Copyright (C) 2007-2009, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2007-2010, David Beckett http://www.dajobe.org/
  * 
  * This file is licensed under the following three licenses as alternatives:
  *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
@@ -174,6 +174,9 @@ typedef enum {
  * @PHOTO_FIELD_original_width: original photo width
  * @PHOTO_FIELD_original_height: original photo height
  * @PHOTO_FIELD_views: number of photo views
+ * @PHOTO_FIELD_comments: number of photo comments
+ * @PHOTO_FIELD_favorites: number of photo favorites
+ * @PHOTO_FIELD_gallery_comment: comment on the photo when used in a gallery
  * @PHOTO_FIELD_none: internal
  * @PHOTO_FIELD_FIRST: internal offset to first in enum list
  * @PHOTO_FIELD_LAST: internal offset to last in enum list
@@ -241,8 +244,11 @@ typedef enum {
   PHOTO_FIELD_original_width,
   PHOTO_FIELD_original_height,
   PHOTO_FIELD_views,
+  PHOTO_FIELD_comments,
+  PHOTO_FIELD_favorites,
+  PHOTO_FIELD_gallery_comment,
   PHOTO_FIELD_FIRST = PHOTO_FIELD_dateuploaded,
-  PHOTO_FIELD_LAST = PHOTO_FIELD_views
+  PHOTO_FIELD_LAST = PHOTO_FIELD_gallery_comment
 } flickcurl_photo_field_type;
 
 
@@ -957,6 +963,40 @@ struct flickcurl_category_s {
 typedef struct flickcurl_category_s flickcurl_category;
 
 
+/**
+ * flickcurl_gallery: 
+ * @id: gallery ID
+ * @url: URL of gallery
+ * @owner: owner NSID
+ * @date_create: creation date of gallery
+ * @date_update: update / last modified date of gallery
+ * @primary_photo: primary photo for the gallery
+ * @count_photos: number of photos in the gallery
+ * @count_videos: number of photos in the gallery
+ * @title: Gallery title
+ * @description: Gallery description
+ *
+ * A photo gallery.
+ *
+ * The list of photos in the gallery is available via the API calls
+ * flickcurl_galleries_getPhotos() or
+ * flickcurl_galleries_getPhotos_params()
+ *
+ */
+typedef struct {
+  char *id;
+  char *url;
+  char *owner;
+  int date_create;
+  int date_update;
+  flickcurl_photo* primary_photo;
+  int count_photos;
+  int count_videos;
+  char *title;
+  char *description;
+} flickcurl_gallery;
+
+
 /**
  * flickcurl_photoset:
  * @id: photoset ID
@@ -1265,7 +1305,47 @@ typedef struct {
   int is_commons;
   int in_gallery;
 } flickcurl_search_params;
-  
+
+
+/**
+ * flickcurl_stat:
+ * @views: number of views of item
+ * @comments: number of comments on item
+ * @favorites: number of item favorites
+ * @name: name assocated with stat (e.g. domain name)
+ * @url: URL associated with stat (e.g. referrer URL)
+ * @searchterms: search term assocated with stat
+ *
+ * Statistics object
+ */
+typedef struct {
+  int views;
+  int comments;
+  int favorites;
+  char *name;
+  char *url;
+  char *searchterms;
+} flickcurl_stat;
+
+
+/**
+ * flickcurl_view_stats
+ * @total: total view
+ * @photos: number of photo views
+ * @photostreams: number of photostream views
+ * @sets: number of set views
+ * @collections: number of collection views
+ *
+ * Total views statistics
+ */
+typedef struct {
+  int total;
+  int photos;
+  int photostreams;
+  int sets;
+  int collections;
+} flickcurl_view_stats;
+
 
 /**
  * flickcurl_size:
@@ -1420,7 +1500,7 @@ typedef struct {
 /* callback handlers */
 
 /**
- * flickcurl_message_handler
+ * flickcurl_message_handler:
  * @user_data: user data pointer
  * @message: error message
  *
@@ -1428,8 +1508,9 @@ typedef struct {
  */
 typedef void (*flickcurl_message_handler)(void *user_data, const char *message);
 
+
 /**
- * flickcurl_tag_handler
+ * flickcurl_tag_handler:
  * @user_data: user data pointer
  * @tag: tag
  *
@@ -1438,6 +1519,28 @@ typedef void (*flickcurl_message_handler)(void *user_data, const char *message);
 typedef void (*flickcurl_tag_handler)(void *user_data, flickcurl_tag* tag);
 
 
+/**
+ * flickcurl_curl_setopt_handler:
+ * @user_data: user data pointer
+ * @curl_handle: curl CURL* handle
+ *
+ * Flickcurl curl options handle callback.
+ *
+ * For use with flickcurl_set_curl_setopt_handler() to set curl
+ * handle options once Flickcurl has created the CURL* handle
+ * internally.
+ *
+ * NOTE: The type of @curl_handle is void* so that curl headers are
+ * optional when compiling against flickcurl.
+ *
+ * WARNING: This callback is called with two void args in the order
+ * curl handler user data, curl handle (CURL* pointer) - take care in
+ * getting them correct in implementation.
+ *
+ */
+typedef void (*flickcurl_curl_setopt_handler)(void *user_data, void *curl_handle);
+
+
 /* library constants */
 FLICKCURL_API
 extern const char* const flickcurl_short_copyright_string;
@@ -1469,6 +1572,8 @@ void flickcurl_finish(void);
 /* flickcurl* object constructor */
 FLICKCURL_API
 flickcurl* flickcurl_new(void);
+FLICKCURL_API
+flickcurl* flickcurl_new_with_handle(void* curl_handle);
 
 /* flickcurl* object destructor */
 FLICKCURL_API
@@ -1476,6 +1581,8 @@ void flickcurl_free(flickcurl *fc);
 
 /* flickcurl* object set methods */
 FLICKCURL_API
+void flickcurl_set_curl_setopt_handler(flickcurl *fc, flickcurl_curl_setopt_handler curl_handler, void* curl_handler_data);
+FLICKCURL_API
 void flickcurl_set_service_uri(flickcurl *fc, const char *uri);
 FLICKCURL_API
 void flickcurl_set_upload_service_uri(flickcurl *fc, const char *uri);
@@ -1524,6 +1631,8 @@ void flickcurl_free_collection(flickcurl_collection *collection);
 FLICKCURL_API
 void flickcurl_free_collections(flickcurl_collection** collections);
 FLICKCURL_API
+void flickcurl_free_gallery(flickcurl_gallery *gallery);
+FLICKCURL_API
 void flickcurl_free_tag_namespace(flickcurl_tag_namespace *tag_nspace);
 FLICKCURL_API
 void flickcurl_free_tag_namespaces(flickcurl_tag_namespace** tag_nspaces);
@@ -1707,6 +1816,30 @@ flickcurl_photos_list* flickcurl_favorites_getPublicList_params(flickcurl* fc, c
 FLICKCURL_API
 int flickcurl_favorites_remove(flickcurl* fc, const char* photo_id);
 
+/* flickr.galleries */
+FLICKCURL_API
+int flickcurl_galleries_addPhoto(flickcurl* fc, const char* gallery_id, const char* photo_id, const char* comment_text);
+FLICKCURL_API
+char* flickcurl_galleries_create(flickcurl* fc, const char* title, const char* description, const char* primary_photo_id, char** gallery_url_p);
+FLICKCURL_API
+int flickcurl_galleries_editMeta(flickcurl* fc, const char* gallery_id, const char* title, const char* description);
+FLICKCURL_API
+int flickcurl_galleries_editPhoto(flickcurl* fc, const char* gallery_id, const char* photo_id, const char* new_comment);
+FLICKCURL_API
+int flickcurl_galleries_editPhotos(flickcurl* fc, const char* gallery_id, const char* primary_photo_id, const char** photo_ids_array);
+FLICKCURL_API
+flickcurl_gallery* flickcurl_galleries_getInfo(flickcurl* fc, const char* gallery_id);
+FLICKCURL_API
+flickcurl_gallery** flickcurl_galleries_getList(flickcurl* fc, const char* user_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_gallery** flickcurl_galleries_getListForPhoto(flickcurl* fc, const char* photo_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_photos_list* flickcurl_galleries_getPhotos_params(flickcurl* fc, const char* gallery_id, flickcurl_photos_list_params* list_params);
+FLICKCURL_API
+flickcurl_photo** flickcurl_galleries_getPhotos(flickcurl* fc, const char* gallery_id, const char* extras, int per_page, int page);
+FLICKCURL_API
+void flickcurl_free_galleries(flickcurl_gallery **galleries_object);
+
 /* flickr.groups */
 FLICKCURL_API
 void flickcurl_free_category(flickcurl_category *category);
@@ -1784,6 +1917,14 @@ char* flickcurl_people_findByUsername(flickcurl* fc, const char* username);
 FLICKCURL_API
 flickcurl_person* flickcurl_people_getInfo(flickcurl* fc, const char* user_id);
 FLICKCURL_API
+flickcurl_photos_list* flickcurl_people_getPhotos_params(flickcurl* fc, const char* user_id, int safe_search, const char* min_upload_date, const char* max_upload_date, const char* min_taken_date, const char* max_taken_date, int content_type, int privacy_filter, flickcurl_photos_list_params* list_params);
+FLICKCURL_API
+flickcurl_photo** flickcurl_people_getPhotos(flickcurl* fc, const char* user_id, int safe_search, const char* min_upload_date, const char* max_upload_date, const char* min_taken_date, const char* max_taken_date, int content_type, int privacy_filter, const char* extras, int per_page, int page);
+FLICKCURL_API
+flickcurl_photos_list* flickcurl_people_getPhotosOf_params(flickcurl* fc, const char* user_id, flickcurl_photos_list_params* list_params);
+FLICKCURL_API
+flickcurl_photo** flickcurl_people_getPhotosOf(flickcurl* fc, const char* user_id, const char* extras, int per_page, int page);
+FLICKCURL_API
 flickcurl_group** flickcurl_people_getPublicGroups(flickcurl* fc, const char* user_id);
 FLICKCURL_API
 flickcurl_photo** flickcurl_people_getPublicPhotos(flickcurl* fc, const char* user_id,  const char* extras, int per_page, int page);
@@ -1864,6 +2005,19 @@ int flickcurl_photos_setSafetyLevel(flickcurl* fc, const char* photo_id, int saf
 FLICKCURL_API
 int flickcurl_photos_setTags(flickcurl* fc, const char* photo_id, const char* tags);
 
+/* flickr.photos.people */
+FLICKCURL_API
+int flickcurl_photos_people_add(flickcurl* fc, const char* photo_id, const char* user_id, int person_x, int person_y, int person_w, int person_h);
+FLICKCURL_API
+int flickcurl_photos_people_delete(flickcurl* fc, const char* photo_id, const char* user_id);
+FLICKCURL_API
+int flickcurl_photos_people_deleteCoords(flickcurl* fc, const char* photo_id, const char* user_id);
+FLICKCURL_API
+int flickcurl_photos_people_editCoords(flickcurl* fc, const char* photo_id, const char* user_id, int person_x, int person_y, int person_w, int person_h);
+FLICKCURL_API
+flickcurl_person** flickcurl_photos_people_getList(flickcurl* fc, const char* photo_id);
+
+
 /* flickr.places */
 FLICKCURL_API
 flickcurl_place** flickcurl_places_find(flickcurl* fc, const char* query);
@@ -2040,6 +2194,43 @@ char** flickcurl_reflection_getMethods(flickcurl* fc);
 FLICKCURL_API
 flickcurl_method* flickcurl_reflection_getMethodInfo(flickcurl* fc, const char* name);
 
+/* flickr.stats */
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getCollectionDomains(flickcurl* fc, const char* date, const char* collection_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getCollectionReferrers(flickcurl* fc, const char* date, const char* domain, const char* collection_id, int per_page, int page);
+FLICKCURL_API
+int flickcurl_stats_getCollectionStats(flickcurl* fc, const char* date, const char* collection_id);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotoDomains(flickcurl* fc, const char* date, const char* photo_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotoReferrers(flickcurl* fc, const char* date, const char* domain, const char* photo_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat* flickcurl_stats_getPhotoStats(flickcurl* fc, const char* date, const char* photo_id);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotosetDomains(flickcurl* fc, const char* date, const char* photoset_id, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotosetReferrers(flickcurl* fc, const char* date, const char* domain, const char* photoset_id, int per_page, int page);
+FLICKCURL_API
+int flickcurl_stats_getPhotosetStats(flickcurl* fc, const char* date, const char* photoset_id);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotostreamDomains(flickcurl* fc, const char* date, int per_page, int page);
+FLICKCURL_API
+flickcurl_stat** flickcurl_stats_getPhotostreamReferrers(flickcurl* fc, const char* date, const char* domain, int per_page, int page);
+FLICKCURL_API
+int flickcurl_stats_getPhotostreamStats(flickcurl* fc, const char* date);
+FLICKCURL_API
+flickcurl_photo** flickcurl_stats_getPopularPhotos(flickcurl* fc, const char* date, const char* sort, int per_page, int page, const char* extras);
+FLICKCURL_API
+flickcurl_view_stats* flickcurl_stats_getTotalViews(flickcurl* fc, const char* date);
+
+FLICKCURL_API
+void flickcurl_free_stat(flickcurl_stat *stat);
+FLICKCURL_API
+void flickcurl_free_stats(flickcurl_stat **stats_object);
+FLICKCURL_API
+void flickcurl_free_view_stats(flickcurl_view_stats *view_stats);
+
 /* flickr.tag */
 FLICKCURL_API
 flickcurl_photos_list* flickcurl_tags_getClusterPhotos(flickcurl* fc, const char* tag, const char* cluster_id, flickcurl_photos_list_params* list_params);
@@ -2074,6 +2265,8 @@ char* flickcurl_urls_getUserPhotos(flickcurl* fc, const char* user_id);
 FLICKCURL_API
 char* flickcurl_urls_getUserProfile(flickcurl* fc, const char* user_id);
 FLICKCURL_API
+char* flickcurl_urls_lookupGallery(flickcurl* fc, const char* url);
+FLICKCURL_API
 char* flickcurl_urls_lookupGroup(flickcurl* fc, const char* url);
 FLICKCURL_API
 char* flickcurl_urls_lookupUser(flickcurl* fc, const char* url);
