@@ -123,7 +123,7 @@ flickcurl_arg** flickcurl_build_args(flickcurl* fc, xmlXPathContextPtr xpathCtx,
 
 /* blog.c */
 flickcurl_blog** flickcurl_build_blogs(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* blog_count_p);
-flickcurl_blog_service** flickcurl_build_blog_Services(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* blog_services_count_p);
+flickcurl_blog_service** flickcurl_build_blog_services(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* blog_services_count_p);
 
 /* collection.c */
 flickcurl_collection** flickcurl_build_collections(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* collection_count_p);
@@ -169,6 +169,9 @@ flickcurl_context** flickcurl_build_contexts(flickcurl* fc, xmlDocPtr doc);
 /* exif.c */
 flickcurl_exif** flickcurl_build_exifs(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* exif_count_p);
 
+/* activity.c */
+flickcurl_gallery** flickcurl_build_galleries(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* gallery_count_p);
+
 /* group.c */
 flickcurl_group** flickcurl_build_groups(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* group_count_p);
 
@@ -224,6 +227,9 @@ flickcurl_shapedata* flickcurl_build_shape(flickcurl* fc, xmlXPathContextPtr xpa
 /* size.c */
 flickcurl_size** flickcurl_build_sizes(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* size_count_p);
 
+/* stat.c */
+flickcurl_stat** flickcurl_build_stats(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* stat_count_p);
+
 /* tags.c  */
 flickcurl_tag** flickcurl_build_tags(flickcurl* fc, flickcurl_photo* photo, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* tag_count_p);
 flickcurl_tag** flickcurl_build_tags_from_string(flickcurl* fc, flickcurl_photo* photo, const char *string, int *tag_count_p);
@@ -355,6 +361,9 @@ struct flickcurl_s {
   char *replace_service_uri;
 
   unsigned int uri_len;
+
+  flickcurl_curl_setopt_handler curl_setopt_handler;
+  void* curl_setopt_handler_data;
 };
 
 struct flickcurl_serializer_s
