@@ -2,7 +2,7 @@
  *
  * photo.c - Flickcurl photo functions
  *
- * Copyright (C) 2007-2009, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2007-2010, David Beckett http://www.dajobe.org/
  * 
  * This file is licensed under the following three licenses as alternatives:
  *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
@@ -92,7 +92,10 @@ static const char* flickcurl_photo_field_label[PHOTO_FIELD_LAST+1] = {
   "owner_iconfarm",
   "original_width",
   "original_height",
-  "views"
+  "views",
+  "comments",
+  "favorites",
+  "gallery_comment"
 };
 
 
@@ -917,6 +920,30 @@ static struct {
     VALUE_TYPE_INTEGER
   }
   ,
+  {
+    (const xmlChar*)"./stats/@views",
+    PHOTO_FIELD_views,
+    VALUE_TYPE_INTEGER
+  }
+  ,
+  {
+    (const xmlChar*)"./stats/@comments",
+    PHOTO_FIELD_comments,
+    VALUE_TYPE_INTEGER
+  }
+  ,
+  {
+    (const xmlChar*)"./stats/@favorites",
+    PHOTO_FIELD_favorites,
+    VALUE_TYPE_INTEGER
+  }
+  ,
+  {
+    (const xmlChar*)"./comment",
+    PHOTO_FIELD_gallery_comment,
+    VALUE_TYPE_STRING
+  }
+  ,
   { 
     NULL,
     (flickcurl_photo_field_type)0,
@@ -1041,6 +1068,12 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
 
         case VALUE_TYPE_INTEGER:
         case VALUE_TYPE_BOOLEAN:
+          if(!*string_value && datatype == VALUE_TYPE_BOOLEAN) {
+            /* skip setting field with a boolean value '' */
+            special = 1;
+            break;
+          }
+
           int_value = atoi(string_value);
           break;
 
